function I = QoI ( x, y, mu, sigma, PDE_rhs )

%*****************************************************************************80
%
%% QoI() calls PDE_solver() to evaluate the quantity of interest.
%
%  Input:
%
%    x: equispaced discretization nodes
%
%    y: random variables (vector of size 1 x N_rv)
%
%    mu: mean of the random field to be constructed
%
%    sigma=[sigma_1 ... sigma_N_rv]: variance of each part of the random field 
%
%    PDE_rhs: function handle of the rhs of the problem, PDE_rhs = @(x) ... 
%    where x is a row vector.
%
%  Output:
%
%    I: spatial integral of u, the quantity of interest.
%
  [ ~, I ] = PDE_solver ( x, y, mu, sigma, PDE_rhs );

  return
end 
